PdfCacheManager class

Manages PDF file caching to disk

Constructors

PdfCacheManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

clearCache() Future<void>
Clears all cached PDFs
getCachedFile(String url) Future<File?>
Gets the cached PDF file if it exists
getCacheFileCount() Future<int>
Gets the number of cached PDF files
getCacheSize() Future<int>
Gets the total size of cached PDFs in bytes
getCacheStats() Future<CacheStats>
Gets cache statistics
isCached(String url) Future<bool>
Checks if a PDF is cached for the given URL
removeCachedPdf(String url) Future<void>
Removes a specific cached PDF
savePdfToCache(String url, List<int> bytes) Future<File>
Saves PDF bytes to cache